# Little R extension

This extension can write data to `LITTLE_R` format for WRF data assimilation.

## Features

- Provide `LittleR` class to write any data to `LITTLE_R` format.
- Write data to a zip file (end with `.zlr`, that is `Zipped Little R file`).
- Read data from the `.zlr` file, so you can create `LITTLE_R` file with the data.